==> lxqt-session_2.2.0.orig.tar.xz: lxqt-session-2.2.0/lxqt-session/translations/lxqt-session_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="347"/>
        <source>Crash Report</source>
        <translation>Relatório de Falha</translation>
    </message>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="348"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; travou muitas vezes. A execução automática do mesmo foi desativada até o próximo login.</translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Configuration file path.</source>
        <translation>Caminho do arquivo de configuração.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <location filename="../src/main.cpp" line="63"/>
        <source>file</source>
        <translation>arquivo</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="63"/>
        <source>Window manager to use.</source>
        <translation>Gerenciador de janelas a ser usado.</translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="89"/>
        <source>DBus Environment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="90"/>
        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Bem-vindo(a) ao LXQt</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="65"/>
        <source>Other ...</source>
        <translation>Outro...</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="66"/>
        <source>Choose your favorite one.</source>
        <translation>Escolha o seu favorito.</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bem-vindo(a) ao LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Por favor, selecione o gerenciador de janelas a ser utilizado.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>Você poderá mudar esta configuração a qualquer momento, indo a Preferências -&gt; Configurações de Sessão do LXQt -&gt; Configurações básicas.</translation>
    </message>
</context>
</TS>

==> lxqt-session-2.3.0.tar.xz: lxqt-session-2.3.0/lxqt-session/translations/lxqt-session_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="347"/>
        <source>Crash Report</source>
        <translation>Relatório de Falha</translation>
    </message>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="348"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; travou muitas vezes. A execução automática do mesmo foi desativada até o próximo login.</translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Configuration file path.</source>
        <translation>Caminho do arquivo de configuração.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <location filename="../src/main.cpp" line="63"/>
        <source>file</source>
        <translation>arquivo</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="63"/>
        <source>Window manager to use.</source>
        <translation>Gerenciador de janelas a ser usado.</translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="89"/>
        <source>DBus Environment</source>
        <translation>Ambiente DBus</translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="90"/>
        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
        <translation>O Ambiente de Ativação DBus não foi atualizado. Alguns aplicativos podem não funcionar corretamente</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Bem-vindo(a) ao LXQt</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="65"/>
        <source>Other ...</source>
        <translation>Outro...</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="66"/>
        <source>Choose your favorite one.</source>
        <translation>Escolha o seu favorito.</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bem-vindo(a) ao LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Por favor, selecione o gerenciador de janelas a ser utilizado.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>Você poderá mudar esta configuração a qualquer momento, indo a Preferências -&gt; Configurações de Sessão do LXQt -&gt; Configurações básicas.</translation>
    </message>
</context>
</TS>
